Imports ionDESK.Abstracts
Imports ionDESK.Addin
Imports System.Windows.Media

Imports ionDESK.Tools
Imports ionDESK.Data.HistoricalDataPointChain
Imports ionDESK.Data
Imports ionDESK.Data.HistoricalDataPoint
Imports ionDESK.Attributes
Imports System.ComponentModel.DataAnnotations


'Make your add-in locatable

'At startup, ionDESK scans for add-ins to use within the current users work session. It scans for add-ins in the following directories :
'ExeFolder \ Data \ Common \ StrategyCenter \ Final \ Addins \ [  My Add-in Folder  ] \ [ MyCustomAddin.ISL.DLL ] 
'ExeFolder \ Addins \ [  My Add-in Folder  ] \ [ MyCustomAddin.ISL.DLL ] 





' ---Patterns ---
' Addins used to indentify patterns in historical data



' INPUT CLASS - ionDESK class used to gather user input / setting for the addin

<Serializable()> Public Class Pattern_TemplateInput
    Inherits ionDESK.Addin.CandleStickPatternInput

    ' Part one
    ' ionDESK's addin structure is very simple and consistent. 
    ' It is based on one class for user input/configuration and a processing class
    ' in the example template we have one input template and one processing class
    ' We suggest placing both classes in the same file per each addin.



    ' You can add a Form separator to separate the areas of the configuration form
    <FormSeparator>
       <DisplayAttribute(Description:="Describe your setting.")>
    Public Property Setting_1 As Decimal


    <DisplayAttribute(Description:="Describe your setting.")>
    Public Property Setting_2 As String




    ' Override : To display sub title with setting value included.
    Public Overrides ReadOnly Property SubTitle As String
        Get
            Return (Symbol & String.Format(" c({0}) u({1}) ", Setting_1, Setting_2)).Trim
        End Get

    End Property

    ' Error check here
    Public Overrides Function IsValid() As Boolean
        Me.Errors.Clear()


        Return MyBase.IsValid()
    End Function






End Class


' PPOCESS CLASS - ionDESK class used to process and generate output based on the users input 
' The Process Class also contain the 'AddinClassInfo' property that defines the addin and other specifiers

Public Class Pattern_Template
    Inherits CandleStickPatternBase

    Private _AddinInfo As AddinClassInfo
    Public Overrides ReadOnly Property AddinInfo As AddinClassInfo
        Get
            If _AddinInfo Is Nothing Then
                _AddinInfo = New AddinClassInfo
                With _AddinInfo
                    .Title = "Pattern Template"
                    .Description = "Describe Pattern."

                    ' Place a unique GUID here for each add-in you create. DONT JUST CHANGE ID by hand, use a GUID generator
                    .UniqueGUID = "00000000-0000-0000-0000-000000000001"

                    .Tag = ""


                    .AddinType = AddinClassInfo.EnumAddinType.Candle_Stick_Pattern

                    '.ChartsMultipleSeries = True
                    .Released = CDate("11/7/2013")

                    .Version = "1.0"

                    ' Add a URL to Quick Info Help
                    .QuickInfoURL = "http://www.mydomain.com/mypath/myhtmlfile.htm"
                End With
            End If

            Return _AddinInfo
        End Get
    End Property

    Public Overloads Function GetData(e As Pattern_TemplateInput) As CandleStickPatternOutput


        Dim t As New CandleStickPatternOutput

        Dim h = e.ionDESK.Data.OHLC(e)


        'we check to see if the data is ready 
        If h.IsDataReady And h.Data.Count > 2 Then

            ' In this simple sample we will find 3 three up candles ( called 3 white soldiers )


            Dim p1 As HistoricalDataPoint
            Dim p2 As HistoricalDataPoint
            Dim p3 As HistoricalDataPoint
            Dim pt As CandleStickPatternOutputItem
            For i = 2 To h.Data.Count - 1
                ' Place code here to calculate the subject pattern
                p1 = h.Data(i)
                p2 = h.Data(i - 1)
                p3 = h.Data(i - 2)

                If p1.IsBullish And p2.IsBullish And p3.IsBullish Then
                    ' all 3 candles are bullish
                    pt = New CandleStickPatternOutputItem()
                    ' We specify the pattern start and end point
                    With pt
                        .StartPoint = New TechnicalOutputItem(p1.Low, p1.Date)
                        .EndPoint = New TechnicalOutputItem(p1.Low, p1.Date)
                    End With
                    'add the PatternOutputItem to the PatternOutput object 
                    t.Data.Add(pt)
                End If


            Next



        Else

            t.Errors.Add("Data not ready!")

        End If
        h = Nothing
        Return t
    End Function


End Class



