﻿Imports ionDESK.Abstracts
Imports ionDESK.Addin
Imports ionDESK.Addin.SignalOutputItem
Imports ionDESK.Data
Imports ionDESK.Attributes
Imports System.Reflection
Imports System.ComponentModel.DataAnnotations
Imports ionDESK.Signal_TemplateInput
Imports ionDESK.Data.HistoricalDataPoint
Imports ionDESK.Data.HistoricalDataPointChain

'Make your add-in locatable

'At startup, ionDESK scans for add-ins to use within the current users work session. It scans for add-ins in the following directories :
'ExeFolder \ Data \ Common \ StrategyCenter \ Final \ Addins \ [  My Add-in Folder  ] \ [ MyCustomAddin.ISL.DLL ] 
'ExeFolder \ Addins \ [  My Add-in Folder  ] \ [ MyCustomAddin.ISL.DLL ] 





' ---Signals ---
' Addins used to signal buy / sell based on historical chart data



' INPUT CLASS - ionDESK class used to gather user input / setting for the addin

<Serializable()> Public Class Signal_TemplateInput
    Inherits Addin.SignalInput

    ' Part one
    ' ionDESK's addin structure is very simple and consistant. 
    ' It is based on one class for user input/configuration and a processing class
    ' in the example template we have one input template and one processing class
    ' We suggest placing both classes in the same file per each addin.


    Public Enum EnumSignalSampleType
        Bullish = 0
        Bearish = 1
    End Enum

    ' You can add a Form separator to separate the areas of the configuration form
    <FormSeparator>
       <DisplayAttribute(Description:="Describe your setting.")>
    Public Property Setting_1 As Decimal

  
    <DisplayAttribute(Description:="Describe your setting.")>
    Public Property Setting_2 As String


    ' Note enumerations turn into combo list on the configuration form
    <DisplayAttribute(Description:="Describe your setting.")>
    Public Property Setting_3 As EnumSignalSampleType = EnumSignalSampleType.Bullish


    ' Override : To display sub title with setting value included.
    Public Overrides ReadOnly Property SubTitle As String
        Get
            Return (Symbol & String.Format(" c({0}) u({1}) r({2})", Setting_1, Setting_2, Setting_3.ToString)).Trim
        End Get

    End Property

    ' Error check here
    Public Overrides Function IsValid() As Boolean
        Me.Errors.Clear()

       
        Return MyBase.IsValid()
    End Function


End Class





' PPOCESS CLASS - ionDESK class used to process and generate output based on the users input 
' The Process Class aslo contain the 'AddinClassInfo' property that defines the addin and other specifiers

<Serializable()> Public Class Signal_Template
    Inherits SignalBase

    Public Overrides ReadOnly Property AddinInfo As AddinClassInfo
        Get
            Dim a As New AddinClassInfo
            With a
                .Title = "[i] Signal Template"
                .Description = "Describe your addin here"

                ' Place a unique GUID here for each add-in you create. DONT JUST CHANGE ID by hand, use a GUID generator
                .UniqueGUID = "00000000-0000-0000-0000-000000000002"

                ' Set Addin Type
                .AddinType = AddinClassInfo.EnumAddinType.Signal

                ' Add a URL to Quick Info Help
                .QuickInfoURL = "http://www.mydomain.com/mypath/myhtmlfile.htm"

                ' Set release date
                .Released = CDate("1/1/2013")

                'See addin help for more details to define the AddinClassInfo class



            End With
            Return a
        End Get
    End Property

    Public Overloads Function GetData(e As Signal_TemplateInput) As SignalOutput

        Dim t As New SignalOutput


        ' Check to see if incoming argument is valid

        If Not e.IsValid Then
            t.Errors.Clear()
            t.Errors.Add(e.Errors)

            If Not t.Errors.HasErrors Then t.Errors.Add("Check input")

            Return t
        End If






        ' Here we getting the chart data and setting 'h'
        Dim h = e.ionDESK.Data.OHLC(e)
       

        ' if data is ready we process our data and return the proper output
        If h.IsDataReady Then
       
            ' Place logic here based on the chart data and return 


            For Each d In h.Data
                ' simply emit a BUY when the close > open
                ' This is very simple, possibly impractical addin
                ' but illustrates how to emit a BUY / SELL signals

                If d.Close > d.Open Then
                    t.Data.Add(New SignalOutputItem(d, EnumSignalType.Buy))
                Else
                    t.Data.Add(New SignalOutputItem(d, EnumSignalType.Sell))
                End If
            Next



            ' Set the Flag color set by user previously
            ' This for use on charts
            t.Flag_Color = e.Flag_Color


        End If


        h = Nothing



        Return t
    End Function

 

End Class
