Imports ionDESK.Abstracts
Imports ionDESK.Addin
Imports System.Windows.Media

Imports ionDESK.Tools
Imports ionDESK.Data.HistoricalDataPointChain
Imports ionDESK.Data
Imports ionDESK.Data.HistoricalDataPoint
Imports ionDESK.Attributes
Imports System.ComponentModel.DataAnnotations


'Make your add-in locatable

'At startup, ionDESK scans for add-ins to use within the current users work session. It scans for add-ins in the following directories :
'ExeFolder \ Data \ Common \ StrategyCenter \ Final \ Addins \ [  My Add-in Folder  ] \ [ MyCustomAddin.ISL.DLL ] 
'ExeFolder \ Addins \ [  My Add-in Folder  ] \ [ MyCustomAddin.ISL.DLL ] 




' ---Technicals ---
' Addins used to provide data for charts and use within strategies as indicators, lines, and values. 



' INPUT CLASS - ionDESK class used to gather user input / setting for the addin

<Serializable()> Public Class Technical_TemplateInput
    Inherits ionDESK.Addin.TechnicalInput

    ' Part one
    ' ionDESK's addin structure is very simple and consistent. 
    ' It is based on one class for user input/configuration and a processing class
    ' in the example template we have one input template and one processing class
    ' We suggest placing both classes in the same file per each addin.



    ' You can add a Form separator to separate the areas of the configuration form
    <FormSeparator>
       <DisplayAttribute(Description:="Describe your setting.")>
    Public Property Setting_1 As Decimal


    <DisplayAttribute(Description:="Describe your setting.")>
    Public Property Setting_2 As String

    <DisplayAttribute(Description:="Describe your setting.")>
    Public Property Period As Integer = 12


    ' Override : To display sub title with setting value included.
    Public Overrides ReadOnly Property SubTitle As String
        Get
            Return (Symbol & String.Format(" c({0}) u({1}) ", Setting_1, Setting_2)).Trim
        End Get

    End Property

    ' Error check here
    Public Overrides Function IsValid() As Boolean
        Me.Errors.Clear()


        Return MyBase.IsValid()
    End Function






End Class


' PPOCESS CLASS - ionDESK class used to process and generate output based on the users input 
' The Process Class aslo contain the 'AddinClassInfo' property that defines the addin and other specifiers

Public Class Technical_Template
    Inherits TechnicalBase

    Private _AddinInfo As AddinClassInfo
    Public Overrides ReadOnly Property AddinInfo As AddinClassInfo
        Get
            If _AddinInfo Is Nothing Then
                _AddinInfo = New AddinClassInfo
                With _AddinInfo
                    .Title = "Technical Template"
                    .Description = "Describe Technical."

                    ' Place a unique GUID here for each add-in you create. DONT JUST CHANGE ID by hand, use a GUID generator
                    .UniqueGUID = "00000000-0000-0000-0000-000000000001"

                    .Tag = ""

                    .ChartType = AddinClassInfo.EnumChartType.WithStockPrices

                    .AddinType = AddinClassInfo.EnumAddinType.Technical

                    '.ChartsMultipleSeries = True
                    .Released = CDate("11/7/2013")

                    .Version = "1.0"

                    ' Add a URL to Quick Info Help
                    .QuickInfoURL = "http://www.mydomain.com/mypath/myhtmlfile.htm"
                End With
            End If

            Return _AddinInfo
        End Get
    End Property

    Public Overloads Function GetData(e As Technical_TemplateInput) As TechnicalOutput


        Dim t As New TechnicalOutput

        Dim h = e.ionDESK.Data.OHLC(e)


        'we check to see if the data is ready and the count is greater than the minimum data points required
        If h.IsDataReady And h.Data.Count > e.Period Then


            Dim tdc As New TechnicalDataChain("Moving Average")

            Dim p As HistoricalDataPoint
            Dim v As Decimal

            For i = e.Period To h.Data.Count - 1
                ' Place code here to calculate the moving average of available data points
                ' These data points get added to the TechnicalDataChain
                ' In this example we use Linq techniques to iterate our data chain
                ' and take the average of the data points

                v = h.Data.Skip(i - e.Period).Take(e.Period).Average(Function(o) o.Close)
                p = h.Data(i)
                tdc.Data.Add(New TechnicalOutputItem(v, p.Date))

            Next

            ' Finally the TechnicalDataChain gets added to the Technical Output collection
            ' This collection allows the developer to add multiple technicals i.e. Bollinger Bands
            t.Data.Add(tdc)

        Else

            t.Errors.Add("Data not ready!")

        End If
        h = Nothing
        Return t
    End Function


End Class



